<?php
/*
Plugin Name: FairShare
Plugin URI: http://fairshare.attributor.com
Description: FairShare
Version: 1.4
Author: Attributor Corp.
Author URI: http://attributor.com
*/

/*  Copyright 2010 Attributor Corp. (email : fairshare@attributor.com)

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

	This plugin installs the Attributor FairShare content syndication widget. Please register at http://fairshare.attributor.com before you install this plugin.
	    
*/
?>
<?php 

include('fairshare-api.php');
include('fairshare-analytics.php');

define ('FAIRSHARE_POSTS', 'fairshare_posts');
define ('FAIRSHARE_ACCOUNT_ID', 'fairshare_account_id');
define ('FAIRSHARE_WIDGET_POSITION', 'fairshare_widget_position');
define ('FAIRSHARE_PLUGIN_ACTIVE', 'fairshare_plugin_active');
define ('FAIRSHARE_WIDGET_CALL_URL', 'http://widgets.attributor.com/fsw-2.0/fsw/j/fssynwidget-final.min.js');
define ('FAIRSHARE_CLIPBOARD_JS_CALL_URL', 'http://widgets.attributor.com/fsw-2.0/fsw/j/ZeroClipboard-final.min.js');

//wp_posts table columns
define('POST_URL', 'guid');
define ('POST_TITLE', 'post_title');
define ('POST_CONTENT', 'post_content');

register_activation_hook(__FILE__,'activate_fairshare');
register_deactivation_hook(__FILE__,'deactivate_fairshare');
add_action('admin_menu', 'add_fairshare_section_to_posts');
add_action('publish_post', 'save_fairshare_selection');
add_action('admin_menu', 'add_fairshare_settings_page');
add_filter('the_content','display_fairshare_widget');

/* attributor PLUGIN INSTALL */
function activate_fairshare()
{
	try{
		global $wpdb;

		//Create a table which will have the post ids for which FairShare is enabled.
		$table=$wpdb->prefix.FAIRSHARE_POSTS;
		$structure = "CREATE TABLE IF NOT EXISTS ". $table." (
					  id INT(9) NOT NULL AUTO_INCREMENT,
					  post_id VARCHAR(255) NOT NULL,        
					  UNIQUE KEY id (id)
		);";

		require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
		dbDelta($structure);
		
		$fairshareWidgetPosition = get_option(FAIRSHARE_WIDGET_POSITION);
		
		update_option(FAIRSHARE_PLUGIN_ACTIVE, 'true');
		
		if(empty($fairshareWidgetPosition)){
			add_option(FAIRSHARE_WIDGET_POSITION,'top-left');
		}
		
		$fairShareAnalytics = new FairShareAnalytics();
		$fairShareAnalytics->logFairSharePluginActivity(get_option(FAIRSHARE_ACCOUNT_ID), 0, 0);
		
	}
	catch(Exception $e){
	}
}

/**
 *  Adds a FairShare section to the post page.
 */
function add_fairshare_section_to_posts()
{
	$fairShareAccountId = get_option(FAIRSHARE_ACCOUNT_ID);
	if( function_exists( 'add_meta_box' ) && !empty($fairShareAccountId)) {
		add_meta_box('attributor', __('FairShare'), 'add_fairshare_section', 'page', 'advanced', 'core');
		add_meta_box('attributor', __('FairShare'), 'add_fairshare_section', 'post', 'advanced', 'core');
	}
}

/**
 *  Enable the 'FairShare' checkbox if FairShare was enabled for this post previously or for new posts. 
 */
function add_fairshare_section($post) {
	global $wpdb;

	$page_id=$post->ID;
	$table=$wpdb->prefix.FAIRSHARE_POSTS;
	$structure = "SELECT * FROM ". $table." WHERE post_id=".$post->ID;

	$myrows = $wpdb->get_results($structure);
	$pageName = basename($_SERVER['SCRIPT_FILENAME']);
	?>
		<input type="checkbox" name="enable-fairshare" id="fairshare-checkbox" <?php if (count($myrows) > 0 || $pageName == "post-new.php") echo 'checked'; ?>/>
		<label for="fairshare-checkbox">Show the FairShare widget on this post</label>
		<div style="margin: 10px 0 0 20px">** Only include the FairShare widget on original content that you can claim as your own. <a href="http://fairsharesupport.attributor.com/original-content" target="_blank">More info</a></div>
	<?php
}

/**
 *  Save the post id for which fairshare is enabled, in our fairshare_posts table.
 */
function save_fairshare_selection($post_id)
{
	global $wpdb;

	$table=$wpdb->prefix.FAIRSHARE_POSTS;

	$delete_structure = "delete from ". $table." where post_id=".$post_id;

	$wpdb->query($delete_structure);

	$postAction = $_POST['action'];
	
	if(isset($_POST["enable-fairshare"]) || $postAction === "post-quickpress-publish"){		
		$insert_structure = "insert into ".$table."(post_id) values (".$post_id.")";
		$wpdb->query($insert_structure);
	}
	
	//Now, fetch the data saved in the DB for this post and ingest it into the Attributor System.
	$resultSet = $wpdb->get_row('select * from wp_posts where ID = '.$post_id, ARRAY_A);
	
	if (!empty($resultSet)){
	
		$fairShareAccountId = get_option(FAIRSHARE_ACCOUNT_ID);
		
		$postUrl = $resultSet[POST_URL];
		$postTitle = $resultSet[POST_TITLE];
		$postContent = $resultSet[POST_CONTENT];
		
		$fairShareApi = new FairShareAPI();
		$response = $fairShareApi->ingestSource($fairShareAccountId, $postUrl, $postTitle, $postContent, 0);
		if($response == false){
			// Log the upload response error 
			$fairShareAnalytics = new FairShareAnalytics();
			$fairShareAnalytics->logFairShareError($fairShareAccountId, 0, 3);
		}
	}
}

/**
 * Deactivate the FairShare plugin.
 * Sets the plugin active flag to false 
 */
function deactivate_fairshare(){
	
	// Log the deactivation of the fairshare widget. 
	$fairShareAnalytics = new FairShareAnalytics();
	$fairShareAnalytics->logFairSharePluginActivity(get_option(FAIRSHARE_ACCOUNT_ID), 0, 1);

	update_option(FAIRSHARE_PLUGIN_ACTIVE, 'false');
}

/**
 *  Display the FairShare widget into the post for which FairShare is enabled.
 */
function display_fairshare_widget($content)
{
	
	$fairSharePluginActive = get_option(FAIRSHARE_PLUGIN_ACTIVE);
	
	if($fairSharePluginActive == "false"){
		return $content;
	}
	
	global $wpdb;
	global $post;
	$table = $wpdb->prefix.FAIRSHARE_POSTS;
	
	$resultSetForFairSharePosts = $wpdb->get_row('select * from ' . $table . ' where post_id = '.$post->ID);
	$resultSet = $wpdb->get_row('select * from wp_posts where ID = '.$post->ID, ARRAY_A);
	
	if(!empty($resultSetForFairSharePosts) && !empty($resultSet)){
        
		$pos = get_option(FAIRSHARE_WIDGET_POSITION);
		$fairShareAccountId = get_option(FAIRSHARE_ACCOUNT_ID);
		$articleId = $fairShareAccountId . "|" . $post->ID; 
		$result = "<div widget-watermark='". $articleId . "'>";
		
		$postUrl = $resultSet[POST_URL];
		
		$fairShareWidgetCallScript .= "<input id='atb-fs-account-id-" . $articleId . "' type='hidden' value='" . $fairShareAccountId . "'></input>";
		$fairShareWidgetCallScript .= "<input id='atb-fs-post-url-" . $articleId . "' type='hidden' value='" . $postUrl . "'></input>";
		$fairShareWidgetCallScript .= "<script type='text/javascript' src='" . FAIRSHARE_CLIPBOARD_JS_CALL_URL . "'></script>";
		$fairShareWidgetCallScript .= "<script type='text/javascript' src='" . FAIRSHARE_WIDGET_CALL_URL . "?ref=wp&companyId=" . $fairShareAccountId . "&widgetType=0&articleId=" . $articleId . "'></script>";
		switch($pos){
			case 'top-left':
			    $result .= '<div class="attributor-widget"><div style="width: 134px; float:left;">' . $fairShareWidgetCallScript . 
				'</div></div><div style="clear:both; padding-bottom: 5px;"></div>'.$content;
			break;
			case 'top-right':
				$result .= '<div class="attributor-widget"><div style="width: 134px; float:right;">' . $fairShareWidgetCallScript . 
				'</div></div><div style="clear:both; padding-bottom: 5px;"></div>'.$content;
			break;
			case 'top-center':
				$result .= '<div class="attributor-widget"><div style="width: 134px; margin-left: auto; margin-right: auto;">' . $fairShareWidgetCallScript . 
				'</div></div><div style="clear:both; padding-bottom: 5px;"></div>'.$content;
			break;
			case 'bottom-left':
				$result .= $content.'<div class="attributor-widget "><div style="width: 134px; float: left;">' . $fairShareWidgetCallScript .
			'</div><div style="clear:both; padding-bottom: 5px;"></div></div>';
			break;
			case 'bottom-right':
				$result .= $content.'<div class="attributor-widget "><div style="width: 134px; float: right;">' . $fairShareWidgetCallScript . 
			'</div><div style="clear:both; padding-bottom: 5px;"></div></div>';
			break;
			case 'bottom-center':
				$result .= $content.'<div class="attributor-widget "><div style="width: 134px; margin-left: auto;margin-right: auto;">' . $fairShareWidgetCallScript . 
			'</div><div style="clear:both; padding-bottom: 5px;"></div></div>';
			break;
		}
		$result .= "</div>";
	}
	else{
		$result = $content;
	}
	return $result;
}


function add_fairshare_settings_page(){
	if (function_exists ( "add_submenu_page" )) {
		add_submenu_page('plugins.php','FairShare', 'FairShare','manage_options', __FILE__, 'fairshare_settings');
	}
}

/**
 * Displays the FairShare settings page.
 */
function fairshare_settings(){
	?>
	
	<link type="text/css" rel="stylesheet" href="<?php echo plugin_dir_url(__FILE__) ?>css/fairshare-settings.css"/>

	<div id="fairshare-settings-wrapper" class="wrap">
		<div id="fairshare-settings-page-header" class="float-left">
			<h2>FairShare</h2>
		</div>
		<?php
		global $wpdb;
		
		$fairShareApi = new FairShareAPI();
		
		$fairShareAnalytics = new FairShareAnalytics();
		
		$doesUserKeyExist = false;
		$isValidUserKey = false;
				
		// Save the widget position into the database 
		if (isset($_POST ['save'])) {
			
			// Save the FairShare widget position into the database
			$position = preg_split('/\s/m', $_POST['position']);
			update_option(FAIRSHARE_WIDGET_POSITION,strtolower($position[0]));			
			
			// Display a 'saved' message to the user.
			?>
				<div class="updated">
					<p><strong><?php _e ( 'Your FairShare widget settings have been saved' ); ?></strong></p>
				</div>
			<?php
		}
		// Save the FairShare user key value into the database
		elseif (isset($_POST ['validate'])){
			$inputKey = trim($_POST [$fairShareApi->getFairshareUserKey()]);
			if(!empty($inputKey)){
				$isValidUserKey = $fairShareApi->isValidUserKey($inputKey);
				update_option ( $fairShareApi->getFairshareUserKey(), $inputKey);
				$tempAccountId = $fairShareApi->getFairShareAccountId();
				if (!empty($isValidUserKey) && $isValidUserKey == true && !empty($tempAccountId) && $fairShareApi->getFairShareAccountStatus() == 0) {

					// Log the successful validation of the fairshare user key. 
					$fairShareAnalytics->logFairSharePluginActivity($fairShareApi->getFairShareAccountId(), 0, 2);
					
					?>
						<div class="updated">
							<p><strong><?php _e ( 'FairShare key has been saved.' ); ?></strong></p>
						</div>
					<?php
				}
				else{
					$fairShareAnalytics->logFairShareError($inputKey, 0, 0);
				}
			}
		}
		
		// Read the FairShare user key value from database
		$fairShareUserKey = get_option ( $fairShareApi->getFairshareUserKey());
		// If we have a user key..
		if (!empty($fairShareUserKey)) {

			$doesUserKeyExist = true;
			// Check if it is a valid user key. If so, display the account id and the widget position settings section.
			$isValidUserKey = $fairShareApi->isValidUserKey($fairShareUserKey);
			$tempAccountId = $fairShareApi->getFairShareAccountId();
			if (!empty($isValidUserKey) && $isValidUserKey == true && !empty($tempAccountId) && $fairShareApi->getFairShareAccountStatus() == 0) {
				
				update_option(FAIRSHARE_ACCOUNT_ID, $fairShareApi->getFairShareAccountId());

				$element = '<a id="fs-widget-element" href="#">FairShare widget</a>';
				$pos = get_option(FAIRSHARE_WIDGET_POSITION);
				
				$accountRevenue = $fairShareApi->getRevenueInformation($fairShareUserKey);
				if($accountRevenue && $accountRevenue != -1){
					$accountRevenue = "$" . $accountRevenue;
				}
				else{
					$accountRevenue = "Not Available";
					$fairShareAnalytics->logFairShareError($fairShareApi->getFairShareAccountId(), 0, 1);
				}
				
			?>
				
				<div id="account-id-div" class="float-right">FairShare Account ID: <span><strong><?php echo $fairShareApi->getFairShareAccountId(); ?></strong></span></div>
				<div class="clear">Your FairShare plugin is active. You are free to FairShare your posts with others!</div>
				
				<div id="earnings">
					<div class="float-left">Current Earnings:</div>
					<div class="float-right"> <?php echo $accountRevenue ?> </div>
				</div>
				
				<div class="clear fairshare-settings-sub-header">Usage Guidelines</div>
				
				<div>Please remember to put the FairShare widget on original work that you can claim as your own. FairSharing content that isn't yours may result in 
				suspension of your FairShare account.</div>
				
				<ul>
					<li>Only put the FairShare widget on original posts that you can legitimately claim as your own work.</li>
					
					<li>If you include quotes from others in your posts, be sure to enclose the entire excerpt in "quotation marks"  or <pre><code>&lt;blockquote&gt;excerpted content&lt;/blockquote&gt;</code></pre> tags. This tells FairShare to ignore these sections when assessing the originality of your content.</li>
					
					<li>Don't put the FairShare widget on press releases or other public service announcements you republish.</li>
					
					<li>Don't put the FairShare widget on public domain content such as government documents, transcripts of political speeches or content whose copyright has expired.</li>
				</ul>
				
				<div class="line-gap">For more details and to manage your FairShare account, signin at <a href="https://fairshare.attributor.com/fairshare/homepage?ref=wp" target="_blank">fairshare.attributor.com</a></div>
				
				<div class="line-gap">Have a question or need some help? Send an email to <a href="mailto:support@attributor.com">support@attributor.com</a></div>
				
				<div class="fairshare-settings-sub-header">Widget Position</div>
				
				<div>Please set where you'd like the FairShare widget to appear on your posts.</div>
				
				<div id="widget-position-settings-wrapper">
					<div class="top-bottom-row">
						<div class="bin float-left <?php if($pos =='top-left') echo 'text-color' ?>">Top-Left
							<?php if($pos=='top-left') echo $element ?>
						</div>
						<div class="bin float-left <?php if($pos =='top-center') echo 'text-color' ?>">Top-Center
							<?php if($pos=='top-center') echo $element ?>
						</div>
						<div class="bin float-left <?php if($pos =='top-right') echo 'text-color' ?>">Top-Right
							<?php if($pos=='top-right') echo $element ?>
						</div>
					</div>
					<div id="middle-row">
						<div id="content">Post Content</div>
					</div>
					<div class="top-bottom-row">
						<div class="bin float-left <?php if($pos =='bottom-left') echo 'text-color' ?>">Bottom-Left
							<?php if($pos=='bottom-left') echo $element ?>
						</div>
						<div class="bin float-left <?php if($pos =='bottom-center') echo 'text-color' ?>">Bottom-Center
							<?php if($pos=='bottom-center') echo $element ?>
						</div>
						<div class="bin float-left <?php if($pos =='bottom-right') echo 'text-color' ?>">Bottom-Right
							<?php if($pos=='bottom-right') echo $element ?>
						</div>
					</div>
				</div>
				<script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.3.2/jquery.min.js"></script>
				<script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jqueryui/1.7.2/jquery-ui.js"></script>
			    <script>
			  
				  jQuery(document).ready(function(){
				  
					jQuery("#fs-widget-element").draggable({
							revert: 'invalid',
							helper: 'clone',		
							cursor: 'move'
						}
					);
					
					var divs = $('div.bin'), el = null;
					
					for (var i = 0; i < divs.length; i++) {
						var bin = divs[i];  
			            
						jQuery(bin).droppable({
							accept: "#fs-widget-element",
							activeClass: 'droppable-active',
							hoverClass: 'over',
							drop: function(event, ui){
								$('#fs-widget-element').appendTo(this);
								 $(this).parent().parent().children().children().removeClass('text-color');		
								 $(this).addClass('text-color ui-state-highlight');						
								 jQuery('#position').val($(this).text());	
							}
						});		
					}
				  });
			    </script> 
			 <form method="post" action="">
				<input type="text" style="display:none" name="position" id="position" value="<?php echo get_option(FAIRSHARE_WIDGET_POSITION) ?>"/>
				<input type="submit" value="Save" id="save" name="save"/>
			 </form>
			<?php
				}
				else{
					$tempFairShareUserKey = get_option($fairShareApi->getFairshareUserKey());
					delete_option ($fairShareApi->getFairshareUserKey());
					$isValidUserKey = false;
				}
			}

			if( $doesUserKeyExist == false || $isValidUserKey == false){
			?>
			
				<form class="clear" method="post" action="">
					<div class="updated">
						<p><strong><?php _e ( 'FairShare Key validation required' ); ?></strong></p>
					</div>
					<div>
						In order to FairShare your articles you need to first register at <a href="https://fairshare.attributor.com/fairshare/homepage?ref=wp">fairshare.attributor.com</a> - It's painless and it's free!
					</div>
					<div>
						Once you do that, grab your <a href="https://fairshare.attributor.com/fairshare/getWidget?ref=wp">FairShare Key</a> and paste it below. This will validate the plugin and 
						you can begin FairSharing your articles and earning more money from your work.
					</div>
					<div id="key">
						<div class="float-left">
							<label for="fairshare-key">FairShare Key:</label>
							<input style="width: 300px;" type="text" name="<?php echo $fairShareApi->getFairshareUserKey(); ?>" id="fairshare-key"/>
						</div>
						<?php if($doesUserKeyExist == true && $isValidUserKey == false ){?>
							<div id="invalid-key" class="red float-left">Oops, that didn't work. Please enter a valid key and try again.</div>
						<?php
						}
						?>
					</div>
					<div class="clear">
						<input type="submit" value="Validate FairShare Key" id="validate" name="validate"/>
					</div>
			  </form>
			  <div id="support-container">
			  	<div id="support-div" class="line-gap">Have a question or need some help? Send an email to <a href="mailto:support@attributor.com">support@attributor.com</a></div>
			  </div>
			  <script type="text/javascript">
			  		var eFairshareUserKey = document.getElementById('fairshare-key');
			  		if(eFairshareUserKey){
			  			eFairshareUserKey.focus();
			  		}
			  </script>
			  <?php
			}
			?>
		</div>
<?php
}
?>